==> haskell-implicit-hie-cradle-0.5.0.1-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-4K9RI6cd0Pa85IrVgYupp4
key:                  implicit-hie-cradle-0.5.0.1-4K9RI6cd0Pa85IrVgYupp4
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  2bd420ab978ca18a3ead26ddbc31b7b0
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-4K9RI6cd0Pa85IrVgYupp4
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-4FmiJFMCPWcB9FEOd1mu2u
    filepath-1.4.2.2 hie-bios-0.12.0-6yOk2Dy2R6HIvWDDPiWnxF
    implicit-hie-0.1.2.7-BkK8FNxMIwZAFOWzmUT1C9 process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.5.0.1-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-1DhcO0Jm4XN5QFCB854CcG
key:                  implicit-hie-cradle-0.5.0.1-1DhcO0Jm4XN5QFCB854CcG
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  4f8df62a6278b230ccddaad13782c69e
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-1DhcO0Jm4XN5QFCB854CcG
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-5m7TC0OmR1yJEj0luDg7V3
    filepath-1.4.2.2 hie-bios-0.12.0-6PEIyUxPSveJV8Aqs4qicv
    implicit-hie-0.1.2.7-CX60gne60RaAWujt99xfLA process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
